#!/usr/bin/perl -w
#####
#
#   QOTDCommon.pm
#   written by Kevin Lindsey (kevin@kevlindev.com)
#
#####

#####
#
#   configuration
#
#####
use constant PI => 4*atan2(1,1);

$path_data           = "M-6,29.5 Q33.5,10 35.5,34.5 Q44,14.5 -10,7.5 z";
$path_stroke_color   = "rgb(0,100,0)";
$path_stroke_width   = 2;
$path_fill_color     = "rgb(0,128,0)";
$path_fill_opacity   = 0.5;
$path_transform      = "translate(" .
    generate_integer(-15,15) . "," .
    generate_integer(-15,15) . ")";

$pattern_height      = generate_integer(50,200);
$pattern_half_height = $pattern_height / 2;
$hexagon_side_length = $pattern_half_height / cos(PI/6);
$hexagon_offset      = $pattern_half_height * sin(PI/6)/cos(PI/6);
$hexagon_radius      = $hexagon_side_length/2 + $hexagon_offset;
$pattern_width       = 2*$hexagon_radius + $hexagon_side_length;

$hexagon_radius = round($hexagon_radius);
$pattern_width  = round($pattern_width);

$blur_amount         = 4;
$blur_offset_x       = 5;
$blur_offset_y       = 5;
$blur_lighten_amount = 0.1;

$sidebar_width            = "1in";
$sidebar_background_color = "rgb(128,192,128)";
$background_opacity       = "0.15";

$quote_top_margin  = "1in";
$quote_left_margin = "1.25in";
$quote_color       = "rgb(96,96,144)";

$quotes = [
    {
        author => "Anton Checkov",
        lines  => [
            "Man is what he believes."
        ]
    },
    {
        author => "Buddha",
        lines  => [
            "All that we are is the result",
            "of what we have thought."
        ]
    },
    {
        author => "John Donne",
        lines  => [
            "No man is an island, entire of itself;",
            "every man is a piece of the continent,",
            "a part of the main."
        ]
    },
    {
        author => "Ralph Waldo Emerson",
        lines  => [
            "Nothing great was ever achieved",
            "without enthusiasm"
        ]
    },
    {
        author => "William James",
        lines  => [
            "Genius...means little more than the faculty",
            "of perceiving in an inhabitual way."
        ]
    },
    {
        author => "Helen Keller",
        lines  => [
            "We can do anything we want to do",
            "if we stick to it long enough"
        ]
    },
    {
        author => "Thomas A Kempis",
        lines  => [
            "How sweet it is to love, and to be dissolved",
            "and as it were to bathe myself in thy love."
        ]
    },
    {
        author => "Swami Vivekananda",
        lines  => [
            "We are what our thoughts have made us;",
            "so take care about what you think.",
            "Words are secondary. Thoughts live;",
            "they travel far.",
        ]
    },
];


#####
#
#   round
#
#####
sub round {
    my $num      = shift;
    my $accuracy = shift || 3;
    my $factor   = 10**$accuracy;

    return int( $num * $factor ) / $factor;
}


#####
#
#   generate_integer
#
#####
sub generate_integer {
    my $low  = shift;
    my $high = shift;
    my $diff = $high - $low;

    return int( rand($diff) + $low + 0.5 );
}

1;
