#!/usr/bin/perl -w
#####
#
#   svg_via_print.pl
#   written by Kevin Lindsey (kevin@kevlindev.com)
#
#####

#####
#
#   includes
#
#####
use QOTDCommon;


#####
#
#   main
#
#####
print "Pragma: no-cache\n";
print "Content-type: image/svg+xml\n\n";
print <<EOF;
<?xml version="1.0" standalone="no"?>
<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 20010904//EN"
    "http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
<svg xmlns="http://www.w3.org/2000/svg"
     xmlns:xlink="http://www.w3.org/1999/xlink">
    <style type="text/css"><![CDATA[
        .quote {
            font-size: 28;
            font-weight: bold
        }
        .author {
            font-size: 24;
            font-weight: normal;
            font-style: italic
        }
    ]]></style>
    <defs>
        <path id="elem" d="$path_data"
              transform="$path_transform"
              stroke="$path_stroke_color" stroke-width="$path_stroke_width"
              fill="$path_fill_color" fill-opacity="$path_fill_opacity"/>
        <g id="cluster">
            <use xlink:href="#elem" transform="rotate(0)"/>
            <use xlink:href="#elem" transform="rotate(120)"/>
            <use xlink:href="#elem" transform="rotate(240)"/>
        </g>
        <g id="supercluster">
            <use xlink:href="#cluster"
                 transform="rotate(60) translate($hexagon_radius,0) rotate(60) scale(-1,1)"/>
            <use xlink:href="#cluster"
                 transform="rotate(0) translate($hexagon_radius,0)"/>
            <use xlink:href="#cluster"
                 transform="rotate(-60) translate($hexagon_radius,0) scale(1,-1)"/>
        </g>
        <pattern id="tile" height="$pattern_height" width="$pattern_width"
                 patternUnits="userSpaceOnUse" overflow="visible">
            <use xlink:href="#supercluster"
                 transform="translate(0,$pattern_half_height)"/>
            <use xlink:href="#supercluster"
                 transform="translate($pattern_width,$pattern_half_height) scale(-1,1)"/>
        </pattern>
        <filter id="dropShadow" height="130%" width="130%">
            <feGaussianBlur in="SourceAlpha" stdDeviation="$blur_amount" result="shadow"/>
            <feOffset in="shadow" dx="$blur_offset_x" dy="$blur_offset_y" result="offsetShadow"/>
            <feComponentTransfer in="offsetShadow" result="lighterOffsetShadow">
                <feFuncR type="linear" intercept="$blur_lighten_amount"/>
                <feFuncG type="linear" intercept="$blur_lighten_amount"/>
                <feFuncB type="linear" intercept="$blur_lighten_amount"/>
            </feComponentTransfer>
            <feMerge>
                <feMergeNode in="lighterOffsetShadow"/>
                <feMergeNode in="SourceGraphic"/>
            </feMerge>
        </filter>
    </defs>
    <g>
        <desc>A quote with a tiled background</desc>
        <g>
            <desc>The tiled background</desc>
            <rect width="$sidebar_width" height="100%" fill="$sidebar_background_color"/>
            <rect width="$sidebar_width" height="100%" fill="url(#tile)"/>
            <rect x="$sidebar_width" width="100%" height="100%" opacity="$background_opacity" fill="url(#tile)"/>
        </g>
        <text class="quote" y="$quote_top_margin" fill="$quote_color" filter="url(#dropShadow)">
            <desc>The quote</desc>
EOF

my $index  = generate_integer( 0, @$quotes - 1 );
my $quote  = $quotes->[$index];
my $author = $quote->{author};
my $lines  = $quote->{lines};

foreach ( @$lines ) {
    print "            <tspan x=\"$quote_left_margin\" dy=\"1em\">$_</tspan>\n";
}

print <<EOF;
            <tspan class="author" x="$quote_left_margin" dy="2em">$author</tspan>
        </text>
    </g>
</svg>
EOF

