
/**
 * Title:        DXFtoSVG Translator
 * Description:  AutoCAD r2000 DXF to SVG 1.0 translator
 * Copyright:    Copyright (c) 2000
 * Company:      MMC
 * @author Randy George
 * @version 1.0
 */

import java.io.*;

public class DXFtoSVG {
  static boolean events = true;

  public static void main(String[] args) {
    if (args.length <2) {
      displayUsage();
      System.exit(-1);
    }
    else if (!(new File(args[0])).isFile()) {
      displayUsage();
      System.exit(-1);
    } else {
      if (args[1].toLowerCase().equals("true")) events = true;
      else events = false;
      DXF2SVG(args[0]);
    }
  }

  private static void displayUsage() {
    System.err.println("Usage: DXFtoSVG <DXF file> <add event true/false>");
  }

  private static void DXF2SVG(String Infile) {
    String name = new String(Infile.substring(0,Infile.lastIndexOf('.')));
    String line = "";
    try {
      BufferedReader in = new BufferedReader(new FileReader(Infile));
      PrintWriter out = new PrintWriter(new BufferedWriter
                                        (new FileWriter(name + ".svg")));

      // Output svg head
      out.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
      out.println("<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.0//EN\"");
      out.println("\"http://www.w3.org/TR/SVG/DTD/svg10.dtd\">");
      out.println("<svg width='100%' height='100%' ");
      out.println("preserveAspectRatio='xMidYMax'");
      out.println("\txmlns='http://www.w3.org/2000/svg'");
      out.println("\txmlns:xlink='http://www.w3.org/1999/xlink'");
      out.println("\txmlns:aec='http://www.web-maps.com/2002/aec'>");
      out.println("<title>"+ name +"</title>");
      out.println("<g id='ACTIVE' style='fill:none;stroke:black'>");
      // skip past DXF header
      while (((line = in.readLine()) != null) &&
              (!line.equalsIgnoreCase("ENTITIES"))) {
      }
      // read entities section
      while (((line = in.readLine()) != null) &&
              (!line.equalsIgnoreCase("ENDSEC"))) {
        // translate circle entities
        if (line.equalsIgnoreCase("CIRCLE")) {
          Circle c = new Circle();
          c.readDXFCircle(in);
          c.writeSVGCircle(out);
        }
        // translate light weight polyline entities
        else if (line.equalsIgnoreCase("LWPOLYLINE")) {
          LWPolyline lwp = new LWPolyline();
          lwp.readDXFLWPolyline(in);
          lwp.writeSVGLWPolyline(out);
        }
      }

      // Output svg tail
      out.println("</g>");
      out.println("</svg>");

      in.close();
      out.close();
    }  catch (IOException e) {
      System.out.println("IO Exception:" + Infile);
    }
  }
}


