

/**
 * Title:        DXFtoSVG Translator
 * Description:  AutoCAD r12 DXF to SVG 1.0 translator
 * Copyright:    Copyright (c) 2000
 * Company:      Micro Map & CAD
 * @author Randy George
 * @version 1.0
 */

import java.io.*;
import java.util.*;

public class LWPolyline {
  private ArrayList pts = new ArrayList();
  private boolean closed = false;
  private String layer = "";

  static int id = 0;

  public void readDXFLWPolyline(BufferedReader in) throws IOException  {
    String line;
    Point pt = new Point();

    while (((line = in.readLine()) != null) && (!line.equals("  0"))) {
      if (line.equals("  8"))
        this.layer = in.readLine();
      else if (line.equals(" 70")) {
        line = in.readLine();
        if (line.equals("     1")) closed = true;
        else closed = false;
      }
      else if (line.equals(" 10")) {
        pt = new Point();
        pt.x= Double.parseDouble(in.readLine());
      }
      else if (line.equals(" 20")) {
        pt.y= Double.parseDouble(in.readLine());
        pts.add(pt);
      }
    }
    return;
  }

  public void writeSVGLWPolyline(PrintWriter svg) {
    Point pt;

    svg.print("<polyline ");
    if (DXFtoSVG.events) {
      svg.print("id='LWP" + id++ +"' onmouseover='over(evt)' ");
      svg.print("onmouseout='out(evt)' onclick='click(evt)' ");
      svg.print("style='fill:yellow;fill-opacity:0.25'");
    }
    svg.print(" points='");

    Iterator it = pts.iterator();
    while (it.hasNext()) {
      pt = (Point)it.next();
      svg.print(pt.x + "," + (-pt.y));
      if (it.hasNext()) svg.print(" ");
    }
    if (closed) {
      it = pts.iterator();
      pt = (Point)it.next();
      svg.print(" " + pt.x + "," + (-pt.y));
    }
    if (!layer.equals("")) svg.print("' aec:page='"+layer);
    svg.println("'/>");
  }

  public class Point {
    double x;
    double y;

    Point () {
      x = 0.0;
      y = 0.0;
    }

    public Point(double x, double y) {
      this.x = x;
      this.y = y;
    }
  }
}