

/**
 * Title:        ModifyDOM
 * Description:  Read a SVG DOM generated by Adobe Illustrator 10 and Modify
 * Copyright:    Copyright (c) 2002
 * Company:      MMC
 * @author
 * @version 1.0
 */
  import org.w3c.dom.*;

public class LayerSidebar {
  private Document newdoc;
  private Element newroot;
  private String width;
  private String height;

  public LayerSidebar(Document newdoc, Element newroot, String width, String height) {
    this.newdoc = newdoc;
    this.newroot = newroot;
    this.width = width;
    this.height = height;
  }

  public Document createLayerSidebar(Object[] lyrTable, String name) {
    Node head = newdoc.createElement("head");
    Node title = newdoc.createElement("title");
    Text text = newdoc.createTextNode("Layers -" + name + "a.svg");
    title.appendChild(text);
    head.appendChild(title);
    newroot.appendChild(head);

    //create an inline javascript
    StringBuffer js = new StringBuffer();
    js.append("\nvar layers = new Array(\n");

      boolean first=true;
      for (int i = 0; i < lyrTable.length; i++) {
        String l = (String)lyrTable[i];
        if (!first) { js.append(",\n"); }
        first = false;
        js.append("\"" + l + "\"");
      }
      js.append(");\n");

      js.append("function init() {\n");
      js.append("  for (var i=0;i<layers.length;i++)\n");
      js.append("    window.document.layer_form[i].checked = true;\n");
      js.append("    window.document.layer_form[layers.length-2].checked = false;\n");
      js.append("}\n");

      js.append("function Layerclick(button) {\n");
      js.append("var svgobj;\n");
      js.append("var svgstyle;\n");
      js.append("var svgdoc = window.SVGPage.getSVGDocument();\n");
      js.append("if (button==\"on\") { // all on\n");
      js.append("    var i;\n");
      js.append("    for (i=0;i<layers.length;i++) {\n");
      js.append("      window.document.layer_form[i].checked = true;\n");
      js.append("      svgobj = svgdoc.getElementById(layers[i]);\n");
      js.append("      if (svgobj!=null){\n");
      js.append("        svgstyle = svgobj.getStyle();\n");
      js.append("         svgstyle.setProperty('visibility', 'visible');\n");
      js.append("      }\n");
      js.append("    } \n");
      js.append("    window.document.layer_form[layers.length-2].checked = false;\n");
      js.append("  }\n");
      js.append("  else if (button==\"off\") { // all on\n");
      js.append("    for (i=0;i<layers.length;i++) {\n");
      js.append("      window.document.layer_form[i].checked = false;\n");
      js.append("      svgobj = svgdoc.getElementById(layers[i]);\n");
      js.append("      if (svgobj!=null){\n");
      js.append("        svgstyle = svgobj.getStyle();\n");
      js.append("        svgstyle.setProperty(\"visibility\", \"hidden\");\n");
      js.append("      }\n");
      js.append("    }\n");
      js.append("    window.document.layer_form[layers.length-2].checked = true;\n");
      js.append("  }\n");
      js.append("  else { // change\n");
      js.append("      svgobj = svgdoc.getElementById(button);\n");
      js.append("      if (svgobj!=null){\n");
      js.append("        svgstyle = svgobj.getStyle();\n");
      js.append("        if (window.document.layer_form[button].checked) {\n");
      js.append("          svgstyle.setProperty(\"visibility\", \"visible\");\n");
      js.append("        } else {\n");
      js.append("          svgstyle.setProperty(\"visibility\", \"hidden\");\n");
      js.append("	  }\n");
      js.append("      }\n");
      js.append("  }\n");
      js.append("}\n\\\\");

    Element script =  newdoc.createElement("script");
    Comment comment = newdoc.createComment(js.toString());
    script.appendChild(comment);
    Element body = newdoc.createElement("body");
    body.setAttribute("onload","init()");
    body.appendChild(script);

    Element table = newdoc.createElement("table");
    table.setAttribute("name","layers");
    table.setAttribute("style","font-size:10");
    for (int i = 0; i < lyrTable.length; i++) {
      String l = (String)lyrTable[i];
      //System.out.println(l);
      Element tr = newdoc.createElement("tr");
      Element td = newdoc.createElement("td");
      Element input = newdoc.createElement("input");
      input.setAttribute("type","checkbox");
      input.setAttribute("name",l);
      if (l.equals("All On"))
                input.setAttribute("onclick","Layerclick(\"on\")");
      else if (l.equals("All Off"))
                input.setAttribute("onclick","Layerclick(\"off\")");
      else input.setAttribute("onclick","Layerclick(\"" + l +"\")");
      text = newdoc.createTextNode(l);
      input.appendChild(text);
      td.appendChild(input);
      tr.appendChild(td);
      table.appendChild(tr);
    }
    Element form = newdoc.createElement("form");
    form.setAttribute("name","layer_form");
    form.appendChild(table);
    Element td = newdoc.createElement("td");
    td.appendChild(form);
    table = newdoc.createElement("table");
    table.appendChild(td);

    Element param = newdoc.createElement("param");
    param.setAttribute("name","src");
    param.setAttribute("value",name+"b.svg");
    Element object = newdoc.createElement("object");
    object.setAttribute("type","image/svg+xml");
    object.setAttribute("name","SVGPage");
    object.setAttribute("width",width);
    object.setAttribute("height",height);
    object.appendChild(param);
    td = newdoc.createElement("td");
    td.appendChild(object);

    table.appendChild(td);
    body.appendChild(table);
    newroot.appendChild(body);

    return newdoc;
  }
}