

/**
 * Title:        ModifyDOM
 * Description:  Read a SVG DOM generated by Adobe Illustrator 10 and Modify
 * Copyright:    Copyright (c) 2002
 * Company:      MMC
 * @author
 * @version 1.0
 */

  import java.io.*;
  import java.util.*;
  import org.w3c.dom.*;
  import javax.xml.parsers.*;
  import org.xml.sax.SAXException;
  import org.apache.xml.serialize.XMLSerializer;
  import org.apache.xml.serialize.OutputFormat;

public class ModifyDOM {

  public static void main(String[] args) {
     if (args.length == 0) {
      displayUsage();
      System.exit(-1);
    }
    else if (!(new File(args[0])).isDirectory()) {
      displayUsage();
      System.exit(-1);
    }
    else {
      String path = args[0];
      File dirPath = new File(path);
      String [] fileLst;
      fileLst = dirPath.list(new DirFilter("a.svg"));
      Arrays.sort(fileLst);
      for (int i=0;i<fileLst.length;i++) {
        SVGOutput(dirPath.getAbsolutePath(),fileLst[i]);
      }
    }
  }

   private static void displayUsage() {
    System.err.println("Usage: ModifyDOM <directory>");
  }

  private static void SVGOutput(String path, String infile) {

    Document svgdoc;
    Element svgroot;
    Element activeLyr;
    NodeList nl;
    ArrayList layers = new ArrayList();
    String name, fname;

    try {
      fname = path + File.separator + infile;
      System.out.print("Translating:" + fname);
      name = infile.substring(0,infile.lastIndexOf(".")-1);
      PrintWriter out = new PrintWriter(new BufferedWriter
        (new FileWriter(path + File.separator + name + "b.svg")));
      PrintWriter htm = new PrintWriter(new BufferedWriter
        (new FileWriter(path + File.separator + name + "b.htm")));

      // setup a parser factory
      DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
      factory.setValidating(false);
      factory.setIgnoringElementContentWhitespace(false);
      factory.setNamespaceAware(true);

      DocumentBuilder builder = factory.newDocumentBuilder();

      // read in our file and parse into a DOM tree
      svgdoc = builder.parse(fname);
      svgroot = svgdoc.getDocumentElement();


      // create a new script element
      Element element = svgdoc.createElementNS("http://www.w3.org/2000/svg","script");
      element.setAttribute("type","text/ecmascript");
      element.setAttributeNS("http://www.w3.org/1999/xlink","href","../js/aec.js");
      svgroot.insertBefore(element,svgroot.getFirstChild());


      // declare the xlink namespace
      svgroot.setAttribute("xmlns:xlink","http://www.w3.org/1999/xlink");
      // declare the aec namespace
      svgroot.setAttribute("xmlns:aec","http://www.sams.com/2002/SVGUnleashed/ch23/aec");

      ActivateLayer al = new ActivateLayer();
      activeLyr = al.activate(svgdoc.getElementById("activate-3.5a"));
      // move activated layer to the end of the svg
      if (activeLyr!=null) svgroot.appendChild(
           activeLyr.getParentNode().removeChild(activeLyr));

      activeLyr = al.activate(svgdoc.getElementById("activate-3.6a"));
      // move activated layer to the end of the svg
      if (activeLyr!=null) svgroot.appendChild(
           activeLyr.getParentNode().removeChild(activeLyr));

      ActivateLayerByText altext = new ActivateLayerByText();
      activeLyr = altext.activate(svgdoc.getElementById("active"));
      if (activeLyr!=null) svgroot.appendChild(
           activeLyr.getParentNode().removeChild(activeLyr));

      ActivateLayerByMkno almkno = new ActivateLayerByMkno();
      activeLyr = almkno.activate(svgdoc.getElementById("mkno"));
      if (activeLyr!=null) svgroot.appendChild(
           activeLyr.getParentNode().removeChild(activeLyr));

      // now output our new DOM using the XMLSerializer
      OutputFormat format = new OutputFormat(svgdoc,"UTF-8",true);
      format.setIndent(1);
      format.setLineWidth(0);
      format.setOmitComments(true);

      XMLSerializer serializer = new XMLSerializer((Writer)out,format);
      serializer.serialize(svgdoc);


      //layers for html sidebar
      nl = svgroot.getChildNodes();
      for (int i=0;i<nl.getLength();i++) {
        if ((nl.item(i).getNodeType()!=Element.TEXT_NODE) &&
            (nl.item(i).getNodeName().equals("g"))) {
          Element e = (Element)nl.item(i);
          layers.add(e.getAttribute("id"));
        }
      }
      layers.add("All Off");
      layers.add("All On");

      DOMImplementation dm = builder.getDOMImplementation();
      Document newdoc = dm.createDocument(null,"HTML",null);
      Element newroot = newdoc.getDocumentElement();

      LayerSidebar ls = new LayerSidebar(newdoc,newroot,
      svgroot.getAttribute("width"),svgroot.getAttribute("height"));
      newdoc = ls.createLayerSidebar(layers.toArray(), name);


      format = new OutputFormat(newdoc,"UTF-8",true);
      format.setIndent(1);
      format.setLineWidth(0);
      XMLSerializer htmserializer = new XMLSerializer((Writer)htm,format);
      htmserializer.serialize(newdoc);


      out.close();
      htm.close();
      System.out.println("  Finished");
    } catch (IOException e) {
      System.out.println("IO Error: " + e.getMessage());
    } catch (SAXException e) {
      System.out.println("SAX Excepion: " + e.getMessage());
    } catch (ParserConfigurationException e) {
      System.out.println("Parser Configuration Excepion: " + e.getMessage());
    }
  }
}