

/**
 * Title:        ModifyDOM
 * Description:  DXF to SVG for Sams chapter 26
 * Copyright:    Copyright (c) 2002
 * Company:      MMC
 * @author
 * @version 1.0
 */


import java.io.*;

public class DXFtoSVG {
  static boolean events = true;

  public static void main(String[] args) {
    if (args.length <2) {
      displayUsage();
      System.exit(-1);
    }
    else if (!(new File(args[0])).isFile()) {
      displayUsage();
      System.exit(-1);
    } else {
      if (args[1].toLowerCase().equals("true")) events = true;
      else events = false;
      DXF2SVG(args[0]);
    }
  }

  private static void displayUsage() {
    System.err.println("Usage: DXFtoSVG <DXF file> <add event true/false>");
  }

  private static void DXF2SVG(String Infile) {
    String name = new String(Infile.substring(0,Infile.lastIndexOf('.')));
    String line = "";
    Point maxpt = new Point();
    Point minpt = new Point();
    double dx = 0.0;
    double dy = 0.0;

    try {
      BufferedReader in = new BufferedReader(new FileReader(Infile));
      PrintWriter out = new PrintWriter(new BufferedWriter
                                        (new FileWriter(name + ".svg")));


      //  DXF header
      while (((line = in.readLine()) != null) &&
              (!line.equalsIgnoreCase("ENTITIES"))) {
        // collect Extent Minimum and Maximum fro DXF head
        if (line.equals("$EXTMIN")) {
          minpt.readDXFPoint(in);
        }
        else if (line.equals("$EXTMAX")) {
          maxpt.readDXFPoint(in);
          dx = maxpt.x-minpt.x;
          dy = maxpt.y-minpt.y;
        }
      }
      // Output svg head
      out.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
      out.println("<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.0//EN\"");
      out.println("\"http://www.w3.org/TR/SVG/DTD/svg10.dtd\">");
      out.print("<svg width='800' height='"+(800*Math.abs(dy/dx))+"' ");
      out.println("preserveAspectRatio='xMinYMin'");
      out.println(" viewBox=\"" + minpt.x + " " + dy + " " + dx + " " + -dy + "\"");
      out.println("\tonload=\"on_load(evt)\" onzoom=\"onZoom(evt)\"");
      out.println("\txmlns='http://www.w3.org/2000/svg'");
      out.println("\txmlns:xlink='http://www.w3.org/1999/xlink'");
      out.println("\txmlns:fms='http://www.sams.com/2002/SVGUnleashed/ch26/fms'>");
      out.println("<title>"+ name +"</title>");
      out.println("<script xlink:href=\"../js/fms.js\" type=\"text/ecmascript\"/>");
      out.println("<g id=\"canvas\" onmousemove=\"mousemove(evt)\">");
/*
      out.println("<g id=\"RasterData\" style=\"display:inline;\">");
      out.println("<image x=\"0\" y=\"-7.9\" width=\"10.0\" height=\"7.9\" xlink:href=\"../images/office.jpg\"></image>");
      out.println("</g>");
      out.println("<text transform=\"translate(3 -7)\" style=\"Stroke:white;strok-width:0.001;fill:white;font-size:0.5\">");
      out.println(" <tspan x=\"0\" dy=\"0\">Office Elevation</tspan>");
      out.println(" <tspan x=\"0.5\" dy=\"1em\" style=\"font-size:0.35\">(Select a Floor)</tspan>");
      out.println("</text>");
*/
      out.println("<g id='ACTIVE' style='stroke:black;stroke-width:0.00010;fill:yellow;fill-opacity:0.0'>");


      // read entities section
      while (((line = in.readLine()) != null) &&
              (!line.equalsIgnoreCase("ENDSEC"))) {
        // translate circle entities
        if (line.equalsIgnoreCase("CIRCLE")) {
          Circle c = new Circle();
          c.readDXFCircle(in);
          c.writeSVGCircle(out);
        }
        // translate light weight polyline entities
        else if (line.equalsIgnoreCase("LWPOLYLINE")) {
          LWPolyline lwp = new LWPolyline();
          lwp.readDXFLWPolyline(in);
          lwp.writeSVGLWPolyline(out);
        }
      }

      // Output svg tail
      out.println("</g><!-- Active-->");
      out.println("</g><!-- Canvas-->");
      out.println("</svg>");

      in.close();
      out.close();
    }  catch (IOException e) {
      System.out.println("IO Exception:" + Infile);
    }
  }
}


